<?php
	if ( ! defined( 'ABSPATH' ) ) {
		exit; // Exit if accessed directly.
	}

	if ( ! class_exists( 'WP_List_Table' ) ) {
		require_once( ABSPATH . 'wp-admin/includes/class-wp-list-table.php' );
	}

	class ZLEADSCRM_ANALYTICS_Core_Analytics extends WP_List_Table {
		public $ranges = [];

		public $analytics_data = null;

		public $user_id = 0;

		public $total_bookmarks = 0;

		public $total_leads = 0;

		public $total_leads_created = 0;

		public function __construct( $user_id ) {
			parent::__construct(
				array(
					'singular' => 'analytic',
					'plural'   => 'analytics',
					'ajax'     => false,
				)
			);
			$this->ranges = array(
				'all'        => __( 'All', 'woocommerce' ),
				'year'       => __( 'Year', 'woocommerce' ),
				'last_month' => __( 'Last month', 'woocommerce' ),
				'month'      => __( 'This month', 'woocommerce' ),
				'7day'       => __( 'Last 7 days', 'woocommerce' ),
			);

			$this->user_id = $user_id;

			$this->analytics_data = zleadscrm_get_analytics_data( $this->user_id );
		}

		public function print_overview() {
			$this->prepare_items();
			echo '<div class="zleadscrm_overview_wrap">';
			echo '<h2 class="screen-reader-text">Analytics</h2>';
			?>
            <div class="stats_range">
                <ul>
					<?php
						if ( isset( $_GET['range'] ) ) {
							$current_range = sanitize_text_field( $_GET['range'] );
						} else {
							$current_range = 'all';
							$_GET['range'] = 'all';
						}
						foreach ( $this->ranges as $range => $name ) {
							echo '<li class="' . ( $current_range == $range ? 'active' : '' ) . '"><a href="' . esc_url( remove_query_arg( array(
									'start_date',
									'end_date'
								), add_query_arg( 'range', $range ) ) ) . '">' . esc_html( $name ) . '</a></li>';
						}
					?>
                    <li class="custom <?php echo ( 'custom' === $current_range ) ? 'active' : ''; ?>">
						<?php esc_html_e( 'Custom:', 'woocommerce' ); ?>
                        <form method="GET">
                            <div>
								<?php
									// Maintain query string.
									foreach ( $_GET as $key => $value ) {
										if ( is_array( $value ) ) {
											foreach ( $value as $v ) {
												echo '<input type="hidden" name="' . esc_attr( sanitize_text_field( $key ) ) . '[]" value="' . esc_attr( sanitize_text_field( $v ) ) . '" />';
											}
										} else {
											echo '<input type="hidden" name="' . esc_attr( sanitize_text_field( $key ) ) . '" value="' . esc_attr( sanitize_text_field( $value ) ) . '" />';
										}
									}
								?>
                                <input type="hidden" name="range" value="custom"/>
                                <input type="text" size="11" placeholder="yyyy-mm-dd"
                                       value="<?php echo ( ! empty( $_GET['start_date'] ) ) ? esc_attr( wp_unslash( sanitize_text_field( $_GET['start_date'] ) ) ) : ''; ?>"
                                       name="start_date" class="range_datepicker from" id="start_date_datepicker"
                                       autocomplete="off"/><?php //@codingStandardsIgnoreLine
								?>
                                <span>&ndash;</span>
                                <input type="text" size="11" placeholder="yyyy-mm-dd"
                                       value="<?php echo ( ! empty( $_GET['end_date'] ) ) ? esc_attr( wp_unslash( sanitize_text_field( $_GET['end_date'] ) ) ) : ''; ?>"
                                       name="end_date" class="range_datepicker to" id="end_date_datepicker"
                                       autocomplete="off"/><?php //@codingStandardsIgnoreLine
								?>
                                <button type="submit" class="button"
                                        value="<?php esc_attr_e( 'Go', 'woocommerce' ); ?>"><?php esc_html_e( 'Go', 'woocommerce' ); ?></button>
								<?php wp_nonce_field( 'custom_range', 'wc_reports_nonce', false ); ?>
                            </div>
                        </form>
                    </li>
                </ul>
            </div>
            <div class="zleadscrm_tab_content" id="zleadscrm_report_section"
                 style="margin-top: 10px; box-sizing: border-box; background: white; border: 1px solid #ccc; margin-bottom: 15px;">
                <div class="zleadscrm_row zleadscrm_col_12">

					<?php if ( $this->analytics_data != null ): ?>
                    <div class="zleadscrm_col_4" style="border-right: 1px solid #ccc">
                        <div class="zleadscrm_row" style="margin: 15px 0;">
                            <div class="zleadscrm_col_12">
                                <label><?php echo esc_html( $this->analytics_data['search_requests'] ); ?></label>
                                <span>Total Search Requests</span>
                            </div>
                        </div> <!-- Row End !-->
                    </div> <!-- Col End !-->
                    <div class="zleadscrm_col_4" style="border-right: 1px solid #ccc">
                        <div class="zleadscrm_row" style="margin: 15px 0">
                            <div class="zleadscrm_col_12">
                                <label><?php echo esc_html( $this->analytics_data['basic_results'] ); ?></label>
                                <span>Total Basic Results</span>
                            </div>
                        </div> <!-- Row End !-->
                    </div> <!-- Col End !-->
                    <div class="zleadscrm_col_4">
                        <div class="zleadscrm_row" style="margin: 15px 0">
                            <div class="zleadscrm_col_12">
                                <label><?php echo esc_html( $this->analytics_data['advanced_results'] ); ?></label>
                                <span>Total Advanced Results</span>
                            </div>
                        </div> <!-- Row End !-->
                    </div> <!-- Col End !-->
					<?php if ( class_exists( 'ZACCTMGR_Core' ) ): ?>
                        <div class="zleadscrm_col_4" style="border-right: 1px solid #ccc; border-top: 1px solid #ccc;">
                            <div class="zleadscrm_row" style="margin: 15px 0;">
                                <div class="zleadscrm_col_12">
                                    <label><?php echo esc_html( $this->total_leads ); ?></label>
                                    <span>Total Leads Assigned</span>
                                </div>
                            </div> <!-- Row End !-->
                        </div>
                        <div class="zleadscrm_col_4" style="border-right: 1px solid #ccc; border-top: 1px solid #ccc;">
                            <div class="zleadscrm_row" style="margin: 15px 0;">
                                <div class="zleadscrm_col_12">
                                    <label><?php echo esc_html( $this->total_leads_created ); ?></label>
                                    <span>Total Leads Created</span>
                                </div>
                            </div> <!-- Row End !-->
                        </div>
                        <div class="zleadscrm_col_4" style="border-top: 1px solid #ccc;">
                            <div class="zleadscrm_row" style="margin: 15px 0;">
                                <div class="zleadscrm_col_12">
                                    <label><?php echo esc_html( $this->total_bookmarks ); ?></label>
                                    <span>Total Bookmarks</span>
                                </div>
                            </div> <!-- Row End !-->
                        </div>
					<?php else: ?>
                        <div class="zleadscrm_col_6" style="border-right: 1px solid #ccc; border-top: 1px solid #ccc;">
                            <div class="zleadscrm_row" style="margin: 15px 0;">
                                <div class="zleadscrm_col_12">
                                    <label><?php echo esc_html( $this->total_leads_created ); ?></label>
                                    <span>Total Leads Created</span>
                                </div>
                            </div> <!-- Row End !-->
                        </div>
                        <div class="zleadscrm_col_6" style="border-top: 1px solid #ccc;">
                            <div class="zleadscrm_row" style="margin: 15px 0;">
                                <div class="zleadscrm_col_12">
                                    <label><?php echo esc_html( $this->total_bookmarks ); ?></label>
                                    <span>Total Bookmarks</span>
                                </div>
                            </div> <!-- Row End !-->
                        </div>
					<?php endif; ?>
                </div>

				<?php else: ?>
                    <div class="zleadscrm_row" style="margin: 3rem auto; display: block; text-align: center;">
                        <h2 style="font-size: 26px; color: #737373;">Oops, No Data for Time Period Selected</h2>
                        <h3 style="font-size: 20px; color: #737373;">Try another data range</h3>
                    </div> <!-- Col End !-->
				<?php endif; ?>
            </div> <!-- ACM Tab Content End !-->
			<?php
			$this->display();
			echo '</div>';
		}

		public function column_default( $user, $column_name ) {
			if ( $this->user_id == 0 ) {
				if ( class_exists( 'ZACCTMGR_Core' ) ) {
					switch ( $column_name ) {
						case 'name':
							return '<span>' . $user['name'] . '</span>';
						case 'username':
							return '<span>' . $user['username'] . '</span>';
						case 'leads':
							return '<span>' . $user['leads'] . '</span>';
						case 'leads_created':
							return '<span>' . $user['leads_created'] . '</span>';
						case 'bookmarks':
							return '<span>' . $user['bookmarks'] . '</span>';
						case 'search_functionality':
							return '<span>' . $user['search_functionality'] . '</span>';
						case 'export_functionality':
							return '<span>' . $user['export_functionality'] . '</span>';
						case 'search_request':
							return '<span>' . $user['search_request'] . '</span>';
						case 'basic_results':
							return '<span>' . $user['basic_results'] . '</span>';
						case 'advanced_results':
							return '<span>' . $user['advanced_results'] . '</span>';
						case 'actions':
							ob_start();
							?><p>
							<?php

							$actions['edit'] = array(
								'url'    => add_query_arg( 'user_id', $user['user_id'] ),
								'name'   => 'Edit',
								'action' => 'edit',
								'class'  => 'edit'
							);

							foreach ( $actions as $action ) {
								printf( '<a class="button tips dashicons dashicons-%s" href="%s" style="width: 35px;"></a>', esc_attr( $action['class'] ), esc_url( $action['url'] ) );
							}
							?>
                            </p>
							<?php
							$result_actions = ob_get_contents();
							ob_end_clean();

							return $result_actions;
					}
				} else {
					switch ( $column_name ) {
						case 'name':
							return '<span>' . $user['name'] . '</span>';
						case 'username':
							return '<span>' . $user['username'] . '</span>';
						case 'leads_created':
							return '<span>' . $user['leads_created'] . '</span>';
						case 'bookmarks':
							return '<span>' . $user['bookmarks'] . '</span>';
						case 'search_functionality':
							return '<span>' . $user['search_functionality'] . '</span>';
						case 'export_functionality':
							return '<span>' . $user['export_functionality'] . '</span>';
						case 'search_request':
							return '<span>' . $user['search_request'] . '</span>';
						case 'basic_results':
							return '<span>' . $user['basic_results'] . '</span>';
						case 'advanced_results':
							return '<span>' . $user['advanced_results'] . '</span>';
						case 'actions':
							ob_start();
							?><p>
							<?php

							$actions['edit'] = array(
								'url'    => add_query_arg( 'user_id', $user['user_id'] ),
								'name'   => 'Edit',
								'action' => 'edit',
								'class'  => 'edit'
							);

							foreach ( $actions as $action ) {
								printf( '<a class="button tips dashicons dashicons-%s" href="%s" style="width: 35px;"></a>', esc_attr( $action['class'] ), esc_url( $action['url'] ) );
							}
							?>
                            </p>
							<?php
							$result_actions = ob_get_contents();
							ob_end_clean();

							return $result_actions;
					}
				}
			} else if ( class_exists( 'ZACCTMGR_Core' ) ) {

				switch ( $column_name ) {
					case 'name':
						return '<span>' . $user['name'] . '</span>';
					case 'username':
						return '<span>' . $user['username'] . '</span>';
					case 'leads':
						return '<span>' . $user['leads'] . '</span>';
					case 'leads_created':
						return '<span>' . $user['leads_created'] . '</span>';
					case 'bookmarks':
						return '<span>' . $user['bookmarks'] . '</span>';
					case 'search_functionality':
						return '<span>' . $user['search_functionality'] . '</span>';
					case 'export_functionality':
						return '<span>' . $user['export_functionality'] . '</span>';
					case 'search_request':
						return '<span>' . $user['search_request'] . '</span>';
					case 'basic_results':
						return '<span>' . $user['basic_results'] . '</span>';
					case 'advanced_results':
						return '<span>' . $user['advanced_results'] . '</span>';
				}
			} else {
				switch ( $column_name ) {
					case 'name':
						return '<span>' . $user['name'] . '</span>';
					case 'username':
						return '<span>' . $user['username'] . '</span>';
					case 'leads_created':
						return '<span>' . $user['leads_created'] . '</span>';
					case 'bookmarks':
						return '<span>' . $user['bookmarks'] . '</span>';
					case 'search_functionality':
						return '<span>' . $user['search_functionality'] . '</span>';
					case 'export_functionality':
						return '<span>' . $user['export_functionality'] . '</span>';
					case 'search_request':
						return '<span>' . $user['search_request'] . '</span>';
					case 'basic_results':
						return '<span>' . $user['basic_results'] . '</span>';
					case 'advanced_results':
						return '<span>' . $user['advanced_results'] . '</span>';
				}
			}

			return '';
		}

		public function display_tablenav( $which ) {
			if ( $this->user_id == 0 ) {
				if ( $which == 'top' ) {
					$all_users      = zleadscrm_get_all_eligible_users();
					$active_users   = zleadscrm_get_active_eligible_users();
					$inactive_users = count( $all_users ) - count( $active_users );
					$status         = sanitize_text_field( $_GET['status'] );
					if ( ! isset( $status ) || $status == 'all' ) {
						$all      = 'style="color:#000; font-weight: 700;"';
						$active   = '';
						$inactive = '';
					} else if ( $status == 'inactive' ) {
						$all      = '';
						$active   = '';
						$inactive = 'style="color:#000; font-weight: 700;"';
					} else if ( $status == 'active' ) {
						$all      = '';
						$active   = 'style="color:#000; font-weight: 700;"';
						$inactive = '';
					}


					echo '<ul class="subsubsub">';
					echo '<li style="margin-right:5px;"><a ' . esc_attr( $all ) . ' href="' . add_query_arg( 'status', 'all' ) . '">All <span style="color: #555;">(' . count( $all_users ) . ')</span></a> | </li>';
					echo '<li style="margin-right:5px;"><a ' . esc_attr( $active ) . ' href="' . add_query_arg( 'status', 'active' ) . '">Active <span style="color: #555;">(' . count( $active_users ) . ')</span></a> | </li>';
					echo '<li style="margin-right:5px;"><a ' . esc_attr( $inactive ) . ' href="' . add_query_arg( 'status', 'inactive' ) . '">Inactive <span style="color: #555;">(' . $inactive_users . ')</span></a></li>';
					echo '</ul>';
				}
			}
		}

		public function get_columns() {
			if ( $this->user_id == 0 ) {
				if ( class_exists( 'ZACCTMGR_Core' ) ) {
					$columns = array(
						'name'                 => 'Name',
						'username'             => 'Username',
						'leads'                => 'Leads Assigned',
						'leads_created'        => 'Leads Created',
						'bookmarks'            => 'Bookmarks',
						'search_functionality' => 'Search',
						'export_functionality' => 'Export',
						'search_request'       => 'Search Request',
						'basic_results'        => 'Basic Results',
						'advanced_results'     => 'Advanced Results',
						'actions'              => 'Actions',
					);
				} else {
					$columns = array(
						'name'                 => 'Name',
						'username'             => 'Username',
						'leads_created'        => 'Leads Created',
						'bookmarks'            => 'Bookmarks',
						'search_functionality' => 'Search',
						'export_functionality' => 'Export',
						'search_request'       => 'Search Request',
						'basic_results'        => 'Basic Results',
						'advanced_results'     => 'Advanced Results',
						'actions'              => 'Actions',
					);

				}
			} else if ( class_exists( 'ZACCTMGR_Core' ) ) {
				$columns = array(
					'name'                 => 'Name',
					'username'             => 'Username',
					'leads'                => 'Leads Assigned',
					'leads_created'        => 'Leads Created',
					'bookmarks'            => 'Bookmarks',
					'search_functionality' => 'Search',
					'export_functionality' => 'Export',
					'search_request'       => 'Search Request',
					'basic_results'        => 'Basic Results',
					'advanced_results'     => 'Advanced Results'
				);
			} else {
				$columns = array(
					'name'                 => 'Name',
					'username'             => 'Username',
					'leads_created'        => 'Leads Created',
					'bookmarks'            => 'Bookmarks',
					'search_functionality' => 'Search',
					'export_functionality' => 'Export',
					'search_request'       => 'Search Request',
					'basic_results'        => 'Basic Results',
					'advanced_results'     => 'Advanced Results'
				);
			}

			return $columns;

		}

		public function prepare_items() {
			global $wpdb;
			$table_name = $wpdb->prefix . 'zleadscrm_leads_user_analytics';

			if ( isset( $_GET['status'] ) ) {
				$status = sanitize_text_field( $_GET['status'] );
			} else {
				$status = 'all';
			}


			if ( isset( $_GET['range'] ) ) {
				$range = sanitize_text_field( $_GET['range'] );
			} else {
				$range = 'all';
			}
			switch ( $range ) {
				case '7day':
					$start_date = date( 'Y-m-d 00:00:00', strtotime( '-7 day' ) );
					$end_date   = date( 'Y-m-d 23:59:59' );
					break;
				case 'month':
					$start_date = date( 'Y-m-01 00:00:00' );
					$end_date   = date( 'Y-m-d 23:59:59' );
					break;
				case 'last_month' :
					$start_date = date( 'Y-m-01 00:00:00', strtotime( '-1 month' ) );
					$end_date   = date( 'Y-m-d 23:59:59', strtotime( 'last day of previous month' ) );
					break;
				case 'year':
					$start_date = date( 'Y-01-01 00:00:00' );
					$end_date   = date( 'Y-m-d 23:59:59' );
					break;
				case 'custom':
					$start_date = sanitize_text_field( $_GET['start_date'] );
					$end_date   = sanitize_text_field( $_GET['end_date'] );
					break;
				default:
					$start_date = date( '1970-01-01 00:00:00' );
					$end_date   = date( 'Y-m-d 23:59:59' );
					break;
			}

			if ( $this->user_id == 0 ) {
				$results = $wpdb->get_results( "SELECT user_id, SUM(basic_results) AS basic_results, SUM(advanced_results) AS advanced_results, SUM(basic_requests) AS search_request FROM $table_name WHERE timestamp<='$end_date' AND timestamp>='$start_date' GROUP BY user_id;" );

				$users = [];

				foreach ( $results as $result ) {
					$user = get_user_by( 'id', $result->user_id );
					if ( class_exists( 'ZLEADSCRM_PROSPECT_Core' ) ) {
						$search_functionality = zleadscrm_user_can_do_advanced_search( $user->ID ) == true ? 'Advanced' : ( zleadscrm_user_can_do_basic_search( $user->ID ) == true ? 'Basic' : 'No Rights' );
					} else {
						$search_functionality = 'No Rights';
					}
					if ( class_exists( 'ZLEADSCRM_EXPORT_Core' ) ) {
						$export_functionality = zleadscrm_user_can_export_search( $result->user_id ) == true ? 'yes' : 'no';
					} else {
						$export_functionality = 'no';
					}
					if ( class_exists( 'ZLEADSCRM_PROSPECT_Core' ) ) {
						$bookmarks = zleadscrm_get_number_of_bookmarks( $user->ID );
					} else {
						$bookmarks = 0;
					}
					if ( class_exists( 'ZACCTMGR_Core' ) ) {
						$leads         = zleadscrm_get_number_of_leads( $user->ID );
						$leads_created = zleadscrm_get_number_of_leads_created( $user->ID );
					} else {
						$leads         = 0;
						$leads_created = zleadscrm_get_number_of_leads_created( $user->ID );
					}
					array_push( $users, array(
						'name'                 => $user->last_name . ', ' . $user->first_name,
						'username'             => $user->user_login,
						'leads'                => $leads,
						'leads_created'        => $leads_created,
						'search_functionality' => $search_functionality,
						'export_functionality' => $export_functionality,
						'search_request'       => $result->search_request,
						'basic_results'        => $result->basic_results,
						'advanced_results'     => $result->advanced_results,
						'user_id'              => $result->user_id,
						'bookmarks'            => $bookmarks
					) );
				}

				$selected_roles = zleadscrm_get_selected_roles();
				$inactive_users = [];

				$query = new WP_User_Query( array(
					'role__in' => $selected_roles
				) );

				$all_users = $query->get_results();

				foreach ( $all_users as $user ) {
					if ( ! $this->exist_in_array( $users, $user ) ) {
						if ( class_exists( 'ZLEADSCRM_PROSPECT_Core' ) ) {
							$search_functionality = zleadscrm_user_can_do_advanced_search( $user->ID ) == true ? 'Advanced' : ( zleadscrm_user_can_do_basic_search( $user->ID ) == true ? 'Basic' : 'No Rights' );
						} else {
							$search_functionality = 'No Rights';
						}
						if ( class_exists( 'ZLEADSCRM_EXPORT_Core' ) ) {
							$export_functionality = zleadscrm_user_can_export_search( $user->ID ) == true ? 'yes' : 'no';
						} else {
							$export_functionality = 'no';
						}
						if ( class_exists( 'ZLEADSCRM_PROSPECT_Core' ) ) {
							$bookmarks = zleadscrm_get_number_of_bookmarks( $user->ID );
						}
						if ( class_exists( 'ZACCTMGR_Core' ) ) {
							$leads         = zleadscrm_get_number_of_leads( $user->ID );
							$leads_created = zleadscrm_get_number_of_leads_created( $user->ID );
						} else {
							$leads         = 0;
							$leads_created = zleadscrm_get_number_of_leads_created( $user->ID );
						}
						array_push( $inactive_users, array(
							'name'                 => $user->last_name . ', ' . $user->first_name,
							'username'             => $user->user_login,
							'leads'                => $leads,
							'leads_created'        => $leads_created,
							'search_functionality' => $search_functionality,
							'export_functionality' => $export_functionality,
							'search_request'       => 0,
							'basic_results'        => 0,
							'advanced_results'     => 0,
							'user_id'              => $user->ID,
							'bookmarks'            => $bookmarks
						) );
					}
				}

				if ( $status == 'active' ) {
					$this->items = $users;
				} else if ( $status != 'all' ) {
					$this->items = $inactive_users;
				} else {
					$this->items = $users;
					foreach ( $inactive_users as $inactive_user ) {
						array_push( $this->items, $inactive_user );
					}
				}
			} else {
				$user = get_user_by( 'id', $this->user_id );
				if ( class_exists( 'ZACCTMGR_Core' ) ) {
					$leads         = zleadscrm_get_number_of_leads( $user->ID );
					$leads_created = zleadscrm_get_number_of_leads_created( $user->ID );
				} else {
					$leads_created = zleadscrm_get_number_of_leads_created( $user->ID );
					$leads         = 0;
				}
				$results = $wpdb->get_results( "SELECT user_id, SUM(basic_results) AS basic_results, SUM(advanced_results) AS advanced_results, SUM(basic_requests) AS search_request FROM $table_name WHERE timestamp<='$end_date' AND timestamp>='$start_date' AND user_id=$this->user_id GROUP BY user_id;" );


				if ( class_exists( 'ZLEADSCRM_EXPORT_Core' ) ) {
					$export_functionality = zleadscrm_user_can_export_search( $user->ID ) == true ? 'yes' : 'no';
				} else {
					$export_functionality = 'no';
				}
				if ( class_exists( 'ZLEADSCRM_PROSPECT_Core' ) ) {
					$bookmarks = zleadscrm_get_number_of_bookmarks( $user->ID );
				} else {
					$bookmarks = 0;
				}
				if ( class_exists( 'ZLEADSCRM_PROSPECT_Core' ) ) {
					$search_functionality = zleadscrm_user_can_do_advanced_search( $user->ID ) == true ? 'Advanced' : ( zleadscrm_user_can_do_basic_search( $user->ID ) == true ? 'Basic' : 'No Rights' );
				} else {
					$search_functionality = 'No Rights';
				}
				if ( count( $results ) != 0 ) {
					$search_request   = $results[0]->search_request;
					$basic_results    = $results[0]->basic_results;
					$advanced_results = $results[0]->advanced_results;
				} else {
					$search_request   = 0;
					$basic_results    = 0;
					$advanced_results = 0;
				}


				$this->items = array(
					array(
						'name'                 => $user->last_name . ', ' . $user->first_name,
						'username'             => $user->user_login,
						'leads'                => $leads,
						'leads_created'        => $leads_created,
						'search_functionality' => $search_functionality,
						'export_functionality' => $export_functionality,
						'search_request'       => $search_request,
						'basic_results'        => $basic_results,
						'advanced_results'     => $advanced_results,
						'user_id'              => $user->ID,
						'bookmarks'            => $bookmarks
					)
				);
			}


			foreach ( $this->items as $item ) {
				$this->total_bookmarks     += $item['bookmarks'];
				$this->total_leads         += $item['leads'];
				$this->total_leads_created += $item['leads_created'];
			}


			/**
			 * Init column headers.
			 */
			$this->_column_headers = array( $this->get_columns(), array(), array() );
		}

		private function exist_in_array( $array, $user ) {
			foreach ( $array as $arr ) {
				if ( ( $arr['username'] == $user->user_login ) ) {
					return true;
				}
			}

			return false;
		}

	}


?>